nbrequests: Display Python Requests in Notebook
===============================================

Pretty printing the requests/responses from `python requests <http://requests.readthedocs.io>`_.

Install
-------

::

    pip install nbrequests


Usage
-----

Simply make a request using the python `requests` module and run `display_request()`. Have a look through the `example notebook <https://nbviewer.jupyter.org/github/kristianperkins/nbrequests/blob/master/example_nbrequests.ipynb>`_ for more.
